@@ -13,7 +13,6 @@
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
-* $Id: test_utils.c 2042 2008-08-21 15:18:58Z tonvoon $
 * 
 *****************************************************************************/
 
@@ -30,7 +29,7 @@ main (int argc, char **argv)
 	thresholds *thresholds = NULL;
 	int	rc;
 
-	plan_tests(81);
+	plan_tests(81+23);
 
 	range = parse_range_string("6");
 	ok( range != NULL, "'6' is valid range");
@@ -172,7 +171,85 @@ main (int argc, char **argv)
 
 	test = np_escaped_string("everything");
 	ok( strcmp(test, "everything") == 0, "everything okay");
+
+	/* np_extract_ntpvar tests (23) */
+	test=np_extract_ntpvar("foo=bar, bar=foo, foobar=barfoo\n", "foo");
+	ok(test && !strcmp(test, "bar"), "1st test as expected");
 	free(test);
 
+	test=np_extract_ntpvar("foo=bar,bar=foo,foobar=barfoo\n", "bar");
+	ok(test && !strcmp(test, "foo"), "2nd test as expected");
+	free(test);
+
+	test=np_extract_ntpvar("foo=bar, bar=foo, foobar=barfoo\n", "foobar");
+	ok(test && !strcmp(test, "barfoo"), "3rd test as expected");
+	free(test);
+
+	test=np_extract_ntpvar("foo=bar\n", "foo");
+	ok(test && !strcmp(test, "bar"), "Single test as expected");
+	free(test);
+
+	test=np_extract_ntpvar("foo=bar, bar=foo, foobar=barfooi\n", "abcd");
+	ok(!test, "Key not found 1");
+
+	test=np_extract_ntpvar("foo=bar\n", "abcd");
+	ok(!test, "Key not found 2");
+
+	test=np_extract_ntpvar("foo=bar=foobar", "foo");
+	ok(test && !strcmp(test, "bar=foobar"), "Strange string 1");
+	free(test);
+
+	test=np_extract_ntpvar("foo", "foo");
+	ok(!test, "Malformed string 1");
+
+	test=np_extract_ntpvar("foo,", "foo");
+	ok(!test, "Malformed string 2");
+
+	test=np_extract_ntpvar("foo=", "foo");
+	ok(!test, "Malformed string 3");
+
+	test=np_extract_ntpvar("foo=,bar=foo", "foo");
+	ok(!test, "Malformed string 4");
+
+	test=np_extract_ntpvar(",foo", "foo");
+	ok(!test, "Malformed string 5");
+
+	test=np_extract_ntpvar("=foo", "foo");
+	ok(!test, "Malformed string 6");
+
+	test=np_extract_ntpvar("=foo,", "foo");
+	ok(!test, "Malformed string 7");
+
+	test=np_extract_ntpvar(",,,", "foo");
+	ok(!test, "Malformed string 8");
+
+	test=np_extract_ntpvar("===", "foo");
+	ok(!test, "Malformed string 9");
+
+	test=np_extract_ntpvar(",=,=,", "foo");
+	ok(!test, "Malformed string 10");
+
+	test=np_extract_ntpvar("=,=,=", "foo");
+	ok(!test, "Malformed string 11");
+
+	test=np_extract_ntpvar("  foo=bar  ,\n bar=foo\n , foobar=barfoo  \n  ", "foo");
+	ok(test && !strcmp(test, "bar"), "Random spaces and newlines 1");
+	free(test);
+
+	test=np_extract_ntpvar("  foo=bar  ,\n bar=foo\n , foobar=barfoo  \n  ", "bar");
+	ok(test && !strcmp(test, "foo"), "Random spaces and newlines 2");
+	free(test);
+
+	test=np_extract_ntpvar("  foo=bar  ,\n bar=foo\n , foobar=barfoo  \n  ", "foobar");
+	ok(test && !strcmp(test, "barfoo"), "Random spaces and newlines 3");
+	free(test);
+
+	test=np_extract_ntpvar("  foo=bar  ,\n bar\n \n= \n foo\n , foobar=barfoo  \n  ", "bar");
+	ok(test && !strcmp(test, "foo"), "Random spaces and newlines 4");
+	free(test);
+
+	test=np_extract_ntpvar("", "foo");
+	ok(!test, "Empty string return NULL");
+
 	return exit_status();
 }
