@@ -5,8 +5,6 @@
 * License: GPL
 * Copyright (c) 1999-2007 Nagios Plugins Development Team
 * 
-* Last Modified: $Date: 2008-07-09 22:53:12 +0100 (Wed, 09 Jul 2008) $
-* 
 * Description:
 * 
 * This file contains the check_snmp plugin
@@ -27,18 +25,16 @@
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
-* $Id: check_snmp.c 2021 2008-07-09 21:53:12Z psychotrahe $
 * 
 *****************************************************************************/
 
 const char *progname = "check_snmp";
-const char *revision = "$Revision: 2021 $";
 const char *copyright = "1999-2007";
 const char *email = "nagiosplug-devel@lists.sourceforge.net";
 
 #include "common.h"
 #include "utils.h"
-#include "popen.h"
+#include "utils_cmd.h"
 
 #define DEFAULT_COMMUNITY "public"
 #define DEFAULT_PORT "161"
@@ -47,6 +43,7 @@ const char *email = "nagiosplug-devel@lists.sourceforge.net";
 #define DEFAULT_TIMEOUT 1
 #define DEFAULT_RETRIES 5
 #define DEFAULT_AUTH_PROTOCOL "MD5"
+#define DEFAULT_PRIV_PROTOCOL "DES"
 #define DEFAULT_DELIMITER "="
 #define DEFAULT_OUTPUT_DELIMITER " "
 
@@ -56,33 +53,14 @@ const char *email = "nagiosplug-devel@lists.sourceforge.net";
 #define CRIT_PRESENT 1
 #define CRIT_STRING 2
 #define CRIT_REGEX 4
-#define CRIT_GT 8
-#define CRIT_LT 16
-#define CRIT_GE 32
-#define CRIT_LE 64
-#define CRIT_EQ 128
-#define CRIT_NE 256
-#define CRIT_RANGE 512
-#define WARN_PRESENT 1024
-#define WARN_STRING 2048
-#define WARN_REGEX 4096
-#define WARN_GT 8192
-#define WARN_LT 16384
-#define WARN_GE 32768
-#define WARN_LE 65536
-#define WARN_EQ 131072
-#define WARN_NE 262144
-#define WARN_RANGE 524288
+#define WARN_PRESENT 8
+#define WARN_STRING 16
+#define WARN_REGEX 32
 
 #define MAX_OIDS 8
-#define MAX_DELIM_LENGTH 8
 
 int process_arguments (int, char **);
 int validate_arguments (void);
-char *clarify_message (char *);
-int check_num (int);
-int llu_getll (unsigned long long *, char *);
-int llu_getul (unsigned long long *, char *);
 char *thisarg (char *str);
 char *nextarg (char *str);
 void print_usage (void);
@@ -92,26 +70,27 @@ void print_help (void);
 char regex_expect[MAX_INPUT_BUFFER] = "";
 regex_t preg;
 regmatch_t pmatch[10];
-char timestamp[10] = "";
 char errbuf[MAX_INPUT_BUFFER] = "";
-char perfstr[MAX_INPUT_BUFFER] = "";
+char perfstr[MAX_INPUT_BUFFER] = "| ";
 int cflags = REG_EXTENDED | REG_NOSUB | REG_NEWLINE;
 int eflags = 0;
 int errcode, excode;
 
 char *server_address = NULL;
 char *community = NULL;
-char *authpriv = NULL;
+char **authpriv = NULL;
 char *proto = NULL;
 char *seclevel = NULL;
 char *secname = NULL;
 char *authproto = NULL;
+char *privproto = NULL;
 char *authpasswd = NULL;
 char *privpasswd = NULL;
-char *oid;
+char **oids = NULL;
 char *label;
 char *units;
 char *port;
+char *snmpcmd;
 char string_value[MAX_INPUT_BUFFER] = "";
 char **labels = NULL;
 char **unitv = NULL;
@@ -119,17 +98,16 @@ size_t nlabels = 0;
 size_t labels_size = 8;
 size_t nunits = 0;
 size_t unitv_size = 8;
-int verbose = FALSE;
+int numoids = 0;
+int numauthpriv = 0;
+int verbose = 0;
 int usesnmpgetnext = FALSE;
-unsigned long long lower_warn_lim[MAX_OIDS];
-unsigned long long upper_warn_lim[MAX_OIDS];
-unsigned long long lower_crit_lim[MAX_OIDS];
-unsigned long long upper_crit_lim[MAX_OIDS];
-unsigned long long response_value[MAX_OIDS];
-int check_warning_value = FALSE;
-int check_critical_value = FALSE;
+char *warning_thresholds = NULL;
+char *critical_thresholds = NULL;
+thresholds *thlds[MAX_OIDS];
+double response_value[MAX_OIDS];
 int retries = 0;
-unsigned long long eval_method[MAX_OIDS];
+int eval_method[MAX_OIDS];
 char *delimiter;
 char *output_delim;
 char *miblist = NULL;
@@ -139,20 +117,22 @@ int needmibs = FALSE;
 int
 main (int argc, char **argv)
 {
-	int i = 0;
+	int i;
 	int iresult = STATE_UNKNOWN;
-	int found = 0;
-	int result = STATE_DEPENDENT;
-	char input_buffer[MAX_INPUT_BUFFER];
-	char *command_line = NULL;
+	int result = STATE_UNKNOWN;
+	int return_code = 0;
+	int external_error = 0;
+	char **command_line = NULL;
 	char *cl_hidden_auth = NULL;
+	char *oidname = NULL;
 	char *response = NULL;
 	char *outbuff;
-	char *output;
 	char *ptr = NULL;
-	char *p2 = NULL;
 	char *show = NULL;
+	char *th_warn=NULL;
+	char *th_crit=NULL;
 	char type[8] = "";
+	output chld_out, chld_err;
 
 	setlocale (LC_ALL, "");
 	bindtextdomain (PACKAGE, LOCALEDIR);
@@ -162,17 +142,13 @@ main (int argc, char **argv)
 	unitv = malloc (unitv_size);
 	for (i = 0; i < MAX_OIDS; i++)
 		eval_method[i] = CHECK_UNDEF;
-	i = 0;
 
-	oid = strdup ("");
 	label = strdup ("SNMP");
 	units = strdup ("");
 	port = strdup (DEFAULT_PORT);
 	outbuff = strdup ("");
-	output = strdup ("");
 	delimiter = strdup (" = ");
 	output_delim = strdup (DEFAULT_OUTPUT_DELIMITER);
-	/* miblist = strdup (DEFAULT_MIBLIST); */
 	timeout_interval = DEFAULT_TIMEOUT;
 	retries = DEFAULT_RETRIES;
 
@@ -182,97 +158,114 @@ main (int argc, char **argv)
 	if (process_arguments (argc, argv) == ERROR)
 		usage4 (_("Could not parse arguments"));
 
-	/* create the command line to execute */
-		if(usesnmpgetnext == TRUE) {
-		asprintf(&command_line, "%s -t %d -r %d -m %s -v %s %s %s:%s %s",
-			PATH_TO_SNMPGETNEXT, timeout_interval, retries, miblist, proto,
-			authpriv, server_address, port, oid);
-		asprintf(&cl_hidden_auth, "%s -t %d -r %d -m %s -v %s %s %s:%s %s",
-			PATH_TO_SNMPGETNEXT, timeout_interval, retries, miblist, proto,
-			"[authpriv]", server_address, port, oid);
-	}else{
-
-		asprintf (&command_line, "%s -t %d -r %d -m %s -v %s %s %s:%s %s",
-			PATH_TO_SNMPGET, timeout_interval, retries, miblist, proto,
-			authpriv, server_address, port, oid);
-		asprintf(&cl_hidden_auth, "%s -t %d -r %d -m %s -v %s %s %s:%s %s",
-			PATH_TO_SNMPGET, timeout_interval, retries, miblist, proto,
-			"[authpriv]", server_address, port, oid);
+	/* Populate the thresholds */
+	th_warn=warning_thresholds;
+	th_crit=critical_thresholds;
+	for (i=0; i<numoids; i++) {
+		char *w = th_warn ? strndup(th_warn, strcspn(th_warn, ",")) : NULL;
+		char *c = th_crit ? strndup(th_crit, strcspn(th_crit, ",")) : NULL;
+		/* Skip empty thresholds, while avoiding segfault */
+		set_thresholds(&thlds[i],
+		               w ? strpbrk(w, NP_THRESHOLDS_CHARS) : NULL,
+		               c ? strpbrk(c, NP_THRESHOLDS_CHARS) : NULL);
+		if (w) {
+			th_warn=strchr(th_warn, ',');
+			if (th_warn) th_warn++;
+			free(w);
+		}
+		if (c) {
+			th_crit=strchr(th_crit, ',');
+			if (th_crit) th_crit++;
+			free(c);
+		}
 	}
-	
-	if (verbose)
-		printf ("%s\n", command_line);
-	
 
-	/* run the command */
-	child_process = spopen (command_line);
-	if (child_process == NULL) {
-		printf (_("Could not open pipe: %s\n"), cl_hidden_auth);
+	/* Create the command array to execute */
+	if(usesnmpgetnext == TRUE) {
+		snmpcmd = strdup (PATH_TO_SNMPGETNEXT);
+	}else{
+		snmpcmd = strdup (PATH_TO_SNMPGET);
+	}
+
+	/* 9 arguments to pass before authpriv options + 1 for host and numoids. Add one for terminating NULL */
+	command_line = calloc (9 + numauthpriv + 1 + numoids + 1, sizeof (char *));
+	command_line[0] = snmpcmd;
+	command_line[1] = strdup ("-t");
+	asprintf (&command_line[2], "%d", timeout_interval);
+	command_line[3] = strdup ("-r");
+	asprintf (&command_line[4], "%d", retries);
+	command_line[5] = strdup ("-m");
+	command_line[6] = strdup (miblist);
+	command_line[7] = "-v";
+	command_line[8] = strdup (proto);
+
+	for (i = 0; i < numauthpriv; i++) {
+		command_line[9 + i] = authpriv[i];
+	}
+
+	asprintf (&command_line[9 + numauthpriv], "%s:%s", server_address, port);
+
+	/* This is just for display purposes, so it can remain a string */
+	asprintf(&cl_hidden_auth, "%s -t %d -r %d -m %s -v %s %s %s:%s",
+		snmpcmd, timeout_interval, retries, strlen(miblist) ? miblist : "''", proto, "[authpriv]",
+		server_address, port);
+
+	for (i = 0; i < numoids; i++) {
+		command_line[9 + numauthpriv + 1 + i] = oids[i];
+		asprintf(&cl_hidden_auth, "%s %s", cl_hidden_auth, oids[i]);	
+	}
+
+	command_line[9 + numauthpriv + 1 + numoids] = NULL;
+
+	if (verbose)
+		printf ("%s\n", cl_hidden_auth);
+
+	/* Run the command */
+	return_code = cmd_run_array (command_line, &chld_out, &chld_err, 0);
+
+	/* Due to net-snmp sometimes showing stderr messages with poorly formed MIBs,
+	   only return state unknown if return code is non zero or there is no stdout.
+	   Do this way so that if there is stderr, will get added to output, which helps problem diagnosis
+	*/
+	if (return_code != 0)
+		external_error=1;
+	if (chld_out.lines == 0)
+		external_error=1;
+	if (external_error) {
+		if (chld_err.lines > 0) {
+			printf (_("External command error: %s\n"), chld_err.line[0]);
+			for (i = 1; i < chld_err.lines; i++) {
+				printf ("%s\n", chld_err.line[i]);
+			}
+		} else {
+			printf(_("External command error with no output (return code: %d)\n"), return_code);
+		}
 		exit (STATE_UNKNOWN);
 	}
 
-#if 0		/* Removed May 29, 2007 */
-	child_stderr = fdopen (child_stderr_array[fileno (child_process)], "r");
-	if (child_stderr == NULL) {
-		printf (_("Could not open stderr for %s\n"), cl_hidden_auth);
+	if (verbose) {
+		for (i = 0; i < chld_out.lines; i++) {
+			printf ("%s\n", chld_out.line[i]);
+		}
 	}
-#endif
 
-	while (fgets (input_buffer, MAX_INPUT_BUFFER - 1, child_process))
-		asprintf (&output, "%s%s", output, input_buffer);
+	for (i = 0; i < chld_out.lines; i++) {
+		const char *conv = "%.0f";
 
-	if (verbose)
-		printf ("%s\n", output);
-
-	ptr = output;
-
-	strncat(perfstr, "| ", sizeof(perfstr)-strlen(perfstr)-1);
-	while (ptr) {
-		char *foo, *ptr2;
-		unsigned int copylen;
-
-		foo = strstr (ptr, delimiter);
-		copylen = foo-ptr;
-		if (copylen > sizeof(perfstr)-strlen(perfstr)-1)
-			copylen = sizeof(perfstr)-strlen(perfstr)-1;
-		ptr2 = ptr;
-		ptr = foo; 
-
-		if (ptr == NULL)
+		ptr = chld_out.line[i];
+		oidname = strpcpy (oidname, ptr, delimiter);
+		response = strstr (ptr, delimiter);
+		if (response == NULL)
 			break;
 
-		ptr += strlen (delimiter);
-		ptr += strspn (ptr, " ");
-
-		found++;
-
-		if (ptr[0] == '"') {
-			ptr++;
-			response = strpcpy (response, ptr, "\"");
-			ptr = strpbrk (ptr, "\"");
-			ptr += strspn (ptr, "\"\n");
+		if (verbose > 2) {
+			printf("Processing line %i\n  oidname: %s\n  response: %s\n", i+1, oidname, response);
 		}
-		else {
-			response = strpcpy (response, ptr, "\n");
-			ptr = strpbrk (ptr, "\n");
-			ptr += strspn (ptr, "\n");
-			while
-				(strstr (ptr, delimiter) &&
-				 strstr (ptr, "\n") && strstr (ptr, "\n") < strstr (ptr, delimiter)) {
-				response = strpcat (response, ptr, "\n");
-				ptr = strpbrk (ptr, "\n");
-			}
-			if (ptr && strstr (ptr, delimiter) == NULL) {
-				asprintf (&response, "%s%s", response, ptr);
-				ptr = NULL;
-			}
-		}
-
-		/* We strip out the datatype indicator for PHBs */
 
 		/* Clean up type array - Sol10 does not necessarily zero it out */
 		bzero(type, sizeof(type));
 
+		/* We strip out the datatype indicator for PHBs */
 		if (strstr (response, "Gauge: "))
 			show = strstr (response, "Gauge: ") + 7;
 		else if (strstr (response, "Gauge32: "))
@@ -287,33 +280,25 @@ main (int argc, char **argv)
 		}
 		else if (strstr (response, "INTEGER: "))
 			show = strstr (response, "INTEGER: ") + 9;
-		else if (strstr (response, "STRING: "))
+		else if (strstr (response, "STRING: ")) {
 			show = strstr (response, "STRING: ") + 8;
+			conv = "%.10g";
+		}
+		else if (strstr (response, "Timeticks: "))
+			show = strstr (response, "Timeticks: ");
 		else
 			show = response;
-		p2 = show;
 
 		iresult = STATE_DEPENDENT;
 
 		/* Process this block for integer comparisons */
-		if (eval_method[i] & CRIT_GT ||
-		    eval_method[i] & CRIT_LT ||
-		    eval_method[i] & CRIT_GE ||
-		    eval_method[i] & CRIT_LE ||
-		    eval_method[i] & CRIT_EQ ||
-		    eval_method[i] & CRIT_NE ||
-		    eval_method[i] & WARN_GT ||
-		    eval_method[i] & WARN_LT ||
-		    eval_method[i] & WARN_GE ||
-		    eval_method[i] & WARN_LE ||
-		    eval_method[i] & WARN_EQ ||
-		    eval_method[i] & WARN_NE) {
-			p2 = strpbrk (p2, "0123456789");
-			if (p2 == NULL) 
+		if (thlds[i]->warning || thlds[i]->critical) {
+			ptr = strpbrk (show, "0123456789");
+			if (ptr == NULL)
 				die (STATE_UNKNOWN,_("No valid data returned"));
-			response_value[i] = strtoul (p2, NULL, 10);
-			iresult = check_num (i);
-			asprintf (&show, "%llu", response_value[i]);
+			response_value[i] = strtod (ptr, NULL);
+			iresult = get_status(response_value[i], thlds[i]);
+			asprintf (&show, conv, response_value[i]);
 		}
 
 		/* Process this block for string matching */
@@ -346,7 +331,7 @@ main (int argc, char **argv)
 				iresult = STATE_CRITICAL;
 			else if (eval_method[i] & WARN_PRESENT)
 				iresult = STATE_WARNING;
-			else if (response && iresult == STATE_DEPENDENT) 
+			else if (response && iresult == STATE_DEPENDENT)
 				iresult = STATE_OK;
 		}
 
@@ -366,10 +351,8 @@ main (int argc, char **argv)
 		if (nunits > (size_t)0 && (size_t)i < nunits && unitv[i] != NULL)
 			asprintf (&outbuff, "%s %s", outbuff, unitv[i]);
 
-		i++;
-
 		if (is_numeric(show)) {
-			strncat(perfstr, ptr2, copylen);
+			strncat(perfstr, oidname, sizeof(perfstr)-strlen(perfstr)-1);
 			strncat(perfstr, "=", sizeof(perfstr)-strlen(perfstr)-1);
 			strncat(perfstr, show, sizeof(perfstr)-strlen(perfstr)-1);
 
@@ -377,34 +360,8 @@ main (int argc, char **argv)
 				strncat(perfstr, type, sizeof(perfstr)-strlen(perfstr)-1);
 			strncat(perfstr, " ", sizeof(perfstr)-strlen(perfstr)-1);
 		}
-
-	}	/* end while (ptr) */
-
-	if (found == 0)
-		die (STATE_UNKNOWN,
-			_("%s problem - No data received from host\nCMD: %s\n"),
-			label,
-			cl_hidden_auth);
-
-#if 0		/* Removed May 29, 2007 */
-	/* WARNING if output found on stderr */
-	if (fgets (input_buffer, MAX_INPUT_BUFFER - 1, child_stderr))
-		result = max_state (result, STATE_WARNING);
-
-	/* close stderr */
-	(void) fclose (child_stderr);
-#endif
-
-	/* close the pipe */
-	if (spclose (child_process)) {
-		if (result == STATE_OK)
-			result = STATE_UNKNOWN;
-		asprintf (&outbuff, "%s (%s)", outbuff, _("snmpget returned an error status"));
 	}
 
-/* 	if (nunits == 1 || i == 1) */
-/* 		printf ("%s %s -%s %s\n", label, state_text (result), outbuff, units); */
-/* 	else */
 	printf ("%s %s -%s %s \n", label, state_text (result), outbuff, perfstr);
 
 	return result;
@@ -442,6 +399,7 @@ process_arguments (int argc, char **argv)
 		{"seclevel", required_argument, 0, 'L'},
 		{"secname", required_argument, 0, 'U'},
 		{"authproto", required_argument, 0, 'a'},
+		{"privproto", required_argument, 0, 'x'},
 		{"authpasswd", required_argument, 0, 'A'},
 		{"privpasswd", required_argument, 0, 'X'},
 		{"next", no_argument, 0, 'n'},
@@ -462,7 +420,7 @@ process_arguments (int argc, char **argv)
 	}
 
 	while (1) {
-		c = getopt_long (argc, argv, "nhvVt:c:w:H:C:o:e:E:d:D:s:t:R:r:l:u:p:m:P:L:U:a:A:X:",
+		c = getopt_long (argc, argv, "nhvVt:c:w:H:C:o:e:E:d:D:s:t:R:r:l:u:p:m:P:L:U:a:x:A:X:",
 									 longopts, &option);
 
 		if (c == -1 || c == EOF)
@@ -473,12 +431,12 @@ process_arguments (int argc, char **argv)
 			usage5 ();
 		case 'h':	/* help */
 			print_help ();
-			exit (STATE_OK); 
+			exit (STATE_OK);
 		case 'V':	/* version */
-			print_revision (progname, revision);
+			print_revision (progname, NP_VERSION);
 			exit (STATE_OK);
 		case 'v': /* verbose */
-			verbose = TRUE;
+			verbose++;
 			break;
 
 	/* Connection info */
@@ -491,7 +449,7 @@ process_arguments (int argc, char **argv)
 		case 'p':	/* TCP port number */
 			port = optarg;
 			break;
-		case 'm':	/* List of MIBS  */
+		case 'm':	/* List of MIBS */
 			miblist = optarg;
 			break;
 		case 'n':	/* usesnmpgetnext */
@@ -509,6 +467,9 @@ process_arguments (int argc, char **argv)
 		case 'a':	/* auth protocol */
 			authproto = optarg;
 			break;
+		case 'x':	/* priv protocol */
+			privproto = optarg;
+			break;
 		case 'A':	/* auth passwd */
 			authpasswd = optarg;
 			break;
@@ -523,27 +484,11 @@ process_arguments (int argc, char **argv)
 			break;
 
 	/* Test parameters */
-		case 'c':									/* critical time threshold */
-			if (strspn (optarg, "0123456789:,") < strlen (optarg))
-				usage2 (_("Invalid critical threshold"), optarg);
-			for (ptr = optarg; ptr && jj < MAX_OIDS; jj++) {
-				if (llu_getll (&lower_crit_lim[jj], ptr) == 1)
-					eval_method[jj] |= CRIT_LT;
-				if (llu_getul (&upper_crit_lim[jj], ptr) == 1)
-					eval_method[jj] |= CRIT_GT;
-				(ptr = index (ptr, ',')) ? ptr++ : ptr;
-			}
+		case 'c':									/* critical threshold */
+			critical_thresholds = optarg;
 			break;
-		case 'w':									/* warning time threshold */
-			if (strspn (optarg, "0123456789:,") < strlen (optarg))
-				usage2 (_("Invalid warning threshold"), optarg);
-			for (ptr = optarg; ptr && ii < MAX_OIDS; ii++) {
-				if (llu_getll (&lower_warn_lim[ii], ptr) == 1)
-					eval_method[ii] |= WARN_LT;
-				if (llu_getul (&upper_warn_lim[ii], ptr) == 1)
-					eval_method[ii] |= WARN_GT;
-				(ptr = index (ptr, ',')) ? ptr++ : ptr;
-			}
+		case 'w':									/* warning threshold */
+			warning_thresholds = optarg;
 			break;
 		case 'e': /* PRELIMINARY - may change */
 		case 'E': /* PRELIMINARY - may change */
@@ -561,17 +506,16 @@ process_arguments (int argc, char **argv)
 					 */
 					needmibs = TRUE;
 			}
-
-			for (ptr = optarg; (ptr = index (ptr, ',')); ptr++)
-				ptr[0] = ' '; /* relpace comma with space */
-			for (ptr = optarg; (ptr = index (ptr, ' ')); ptr++)
-				j++; /* count OIDs */
-			asprintf (&oid, "%s %s", (oid?oid:""), optarg);
+			oids = calloc(MAX_OIDS, sizeof (char *));
+			for (ptr = strtok(optarg, ", "); ptr != NULL && j < MAX_OIDS; ptr = strtok(NULL, ", "), j++) {
+				oids[j] = strdup(ptr);
+			}
+			numoids = j;
 			if (c == 'E' || c == 'e') {
 				jj++;
 				ii++;
 			}
-			if (c == 'E') 
+			if (c == 'E')
 				eval_method[j+1] |= WARN_PRESENT;
 			else if (c == 'e')
 				eval_method[j+1] |= CRIT_PRESENT;
@@ -672,8 +616,6 @@ process_arguments (int argc, char **argv)
 
 	if (community == NULL)
 		community = strdup (DEFAULT_COMMUNITY);
-	
-
 
 	return validate_arguments ();
 }
@@ -687,8 +629,8 @@ process_arguments (int argc, char **argv)
 
 <para>&PROTO_validate_arguments;</para>
 
-<para>Checks to see if the default miblist needs to be loaded. Also verifies 
-the authentication and authorization combinations based on protocol version 
+<para>Checks to see if the default miblist needs to be loaded. Also verifies
+the authentication and authorization combinations based on protocol version
 selected.</para>
 
 <para></para>
@@ -704,176 +646,98 @@ validate_arguments ()
 {
 	/* check whether to load locally installed MIBS (CPU/disk intensive) */
 	if (miblist == NULL) {
-		if ( needmibs  == TRUE ) {
+		if ( needmibs == TRUE ) {
 			miblist = strdup (DEFAULT_MIBLIST);
 		}else{
-			miblist = "''";			/* don't read any mib files for numeric oids */
+			miblist = "";			/* don't read any mib files for numeric oids */
 		}
 	}
 
+	/* Check server_address is given */
+	if (server_address == NULL)
+		die(STATE_UNKNOWN, _("No host specified\n"));
 
-	/* Need better checks to verify seclevel and authproto choices */
-	
-	if (seclevel == NULL) 
-		asprintf (&seclevel, "noAuthNoPriv");
+	/* Check oid is given */
+	if (numoids == 0)
+		die(STATE_UNKNOWN, _("No OIDs specified\n"));
 
-
-	if (authproto == NULL ) 
-		asprintf(&authproto, DEFAULT_AUTH_PROTOCOL);
-	
-	 
-	
-	if (proto == NULL || (strcmp(proto,DEFAULT_PROTOCOL) == 0) ) {	/* default protocol version */
+	if (proto == NULL)
 		asprintf(&proto, DEFAULT_PROTOCOL);
-		asprintf(&authpriv, "%s%s", "-c ", community);
-	}
-	else if ( strcmp (proto, "2c") == 0 ) {		/* snmpv2c args */
-		asprintf(&authpriv, "%s%s", "-c ", community);
+
+	if ((strcmp(proto,"1") == 0) || (strcmp(proto, "2c")==0)) {	/* snmpv1 or snmpv2c */
+		numauthpriv = 2;
+		authpriv = calloc (numauthpriv, sizeof (char *));
+		authpriv[0] = strdup ("-c");
+		authpriv[1] = strdup (community);
 	}
 	else if ( strcmp (proto, "3") == 0 ) {		/* snmpv3 args */
-		asprintf(&proto, "%s", "3");
-		
-		if ( (strcmp(seclevel, "noAuthNoPriv") == 0) || seclevel == NULL ) {
-			asprintf(&authpriv, "%s", "-l noAuthNoPriv" );
-		}
-		else if ( strcmp(seclevel, "authNoPriv") == 0 ) {
-			if ( secname == NULL || authpasswd == NULL) {
-				printf (_("Missing secname (%s) or authpassword (%s) ! \n"),secname, authpasswd );
-				print_usage ();
-				exit (STATE_UNKNOWN);
+		if (seclevel == NULL)
+			asprintf(&seclevel, "noAuthNoPriv");
+
+		if (strcmp(seclevel, "noAuthNoPriv") == 0) {
+			numauthpriv = 2;
+			authpriv = calloc (numauthpriv, sizeof (char *));
+			authpriv[0] = strdup ("-l");
+			authpriv[1] = strdup ("noAuthNoPriv");
+		} else {
+			if (! ( (strcmp(seclevel, "authNoPriv")==0) || (strcmp(seclevel, "authPriv")==0) ) ) {
+				usage2 (_("Invalid seclevel"), seclevel);
 			}
-			asprintf(&authpriv, "-l authNoPriv -a %s -u %s -A %s ", authproto, secname, authpasswd);
-		}
-		else if ( strcmp(seclevel, "authPriv") == 0 ) {
-			if ( secname == NULL || authpasswd == NULL || privpasswd == NULL ) {
-				printf (_("Missing secname (%s), authpassword (%s), or privpasswd (%s)! \n"),secname, authpasswd,privpasswd );
-				print_usage ();
-				exit (STATE_UNKNOWN);
+
+			if (authproto == NULL )
+				asprintf(&authproto, DEFAULT_AUTH_PROTOCOL);
+
+			if (secname == NULL)
+				die(STATE_UNKNOWN, _("Required parameter: %s\n"), "secname");
+
+			if (authpasswd == NULL)
+				die(STATE_UNKNOWN, _("Required parameter: %s\n"), "authpasswd");
+
+			if ( strcmp(seclevel, "authNoPriv") == 0 ) {
+				numauthpriv = 8;
+				authpriv = calloc (numauthpriv, sizeof (char *));
+				authpriv[0] = strdup ("-l");
+				authpriv[1] = strdup ("authNoPriv");
+				authpriv[2] = strdup ("-a");
+				authpriv[3] = strdup (authproto);
+				authpriv[4] = strdup ("-u");
+				authpriv[5] = strdup (secname);
+				authpriv[6] = strdup ("-A");
+				authpriv[7] = strdup (authpasswd);
+			} else if ( strcmp(seclevel, "authPriv") == 0 ) {
+				if (privproto == NULL )
+					asprintf(&privproto, DEFAULT_PRIV_PROTOCOL);
+
+				if (privpasswd == NULL)
+					die(STATE_UNKNOWN, _("Required parameter: %s\n"), "privpasswd");
+
+				numauthpriv = 12;
+				authpriv = calloc (numauthpriv, sizeof (char *));
+				authpriv[0] = strdup ("-l");
+				authpriv[1] = strdup ("authPriv");
+				authpriv[2] = strdup ("-a");
+				authpriv[3] = strdup (authproto);
+				authpriv[4] = strdup ("-u");
+				authpriv[5] = strdup (secname);
+				authpriv[6] = strdup ("-A");
+				authpriv[7] = strdup (authpasswd);
+				authpriv[8] = strdup ("-x");
+				authpriv[9] = strdup (privproto);
+				authpriv[10] = strdup ("-X");
+				authpriv[11] = strdup (privpasswd);
 			}
-			asprintf(&authpriv, "-l authPriv -a %s -u %s -A %s -x DES -X %s ", authproto, secname, authpasswd, privpasswd);
 		}
-		
+
 	}
 	else {
 		usage2 (_("Invalid SNMP version"), proto);
 	}
-			
+
 	return OK;
 }
 
 
 
-char *
-clarify_message (char *msg)
-{
-	int i = 0;
-	int foo;
-	char tmpmsg_c[MAX_INPUT_BUFFER];
-	char *tmpmsg = (char *) &tmpmsg_c;
-	tmpmsg = strcpy (tmpmsg, msg);
-	if (!strncmp (tmpmsg, " Hex:", 5)) {
-		tmpmsg = strtok (tmpmsg, ":");
-		while ((tmpmsg = strtok (NULL, " "))) {
-			foo = strtol (tmpmsg, NULL, 16);
-			/* Translate chars that are not the same value in the printers
-			 * character set.
-			 */
-			switch (foo) {
-			case 208:
-				{
-					foo = 197;
-					break;
-				}
-			case 216:
-				{
-					foo = 196;
-					break;
-				}
-			}
-			msg[i] = foo;
-			i++;
-		}
-		msg[i] = 0;
-	}
-	return (msg);
-}
-
-
-
-int
-check_num (int i)
-{
-	int result;
-	result = STATE_OK;
-	if (eval_method[i] & WARN_GT && eval_method[i] & WARN_LT &&
-			lower_warn_lim[i] > upper_warn_lim[i]) {
-		if (response_value[i] <= lower_warn_lim[i] &&
-				response_value[i] >= upper_warn_lim[i]) {
-			result = STATE_WARNING;
-		}
-	}
-	else if
-		((eval_method[i] & WARN_GT && response_value[i] > upper_warn_lim[i]) ||
-		 (eval_method[i] & WARN_GE && response_value[i] >= upper_warn_lim[i]) ||
-		 (eval_method[i] & WARN_LT && response_value[i] < lower_warn_lim[i]) ||
-		 (eval_method[i] & WARN_LE && response_value[i] <= lower_warn_lim[i]) ||
-		 (eval_method[i] & WARN_EQ && response_value[i] == upper_warn_lim[i]) ||
-		 (eval_method[i] & WARN_NE && response_value[i] != upper_warn_lim[i])) {
-		result = STATE_WARNING;
-	}
-
-	if (eval_method[i] & CRIT_GT && eval_method[i] & CRIT_LT &&
-			lower_crit_lim[i] > upper_crit_lim[i]) {
-		if (response_value[i] <= lower_crit_lim[i] &&
-				response_value[i] >= upper_crit_lim[i]) {
-			result = STATE_CRITICAL;
-		}
-	}
-	else if
-		((eval_method[i] & CRIT_GT && response_value[i] > upper_crit_lim[i]) ||
-		 (eval_method[i] & CRIT_GE && response_value[i] >= upper_crit_lim[i]) ||
-		 (eval_method[i] & CRIT_LT && response_value[i] < lower_crit_lim[i]) ||
-		 (eval_method[i] & CRIT_LE && response_value[i] <= lower_crit_lim[i]) ||
-		 (eval_method[i] & CRIT_EQ && response_value[i] == upper_crit_lim[i]) ||
-		 (eval_method[i] & CRIT_NE && response_value[i] != upper_crit_lim[i])) {
-		result = STATE_CRITICAL;
-	}
-
-	return result;
-}
-
-
-
-int
-llu_getll (unsigned long long *ll, char *str)
-{
-	char tmp[100];
-	if (strchr (str, ':') == NULL)
-		return 0;
-	if (strchr (str, ',') != NULL && (strchr (str, ',') < strchr (str, ':')))
-		return 0;
-	if (sscanf (str, "%llu%[:]", ll, tmp) == 2)
-		return 1;
-	return 0;
-}
-
-
-
-int
-llu_getul (unsigned long long *ul, char *str)
-{
-	char tmp[100];
-	if (sscanf (str, "%llu%[^,]", ul, tmp) == 1)
-		return 1;
-	if (sscanf (str, ":%llu%[^,]", ul, tmp) == 1)
-		return 1;
-	if (sscanf (str, "%*u:%llu%[^,]", ul, tmp) == 1)
-		return 1;
-	return 0;
-}
-
-
-
 /* trim leading whitespace
 	 if there is a leading quote, make sure it balances */
 
@@ -928,13 +792,13 @@ nextarg (char *str)
 void
 print_help (void)
 {
-	print_revision (progname, revision);
+	print_revision (progname, NP_VERSION);
 
 	printf (COPYRIGHT, copyright, email);
 
-	printf ("%s\n", _("Check status of remote machines and obtain sustem information via SNMP"));
+	printf ("%s\n", _("Check status of remote machines and obtain system information via SNMP"));
 
-  printf ("\n\n");
+	printf ("\n\n");
 
 	print_usage ();
 
@@ -945,88 +809,84 @@ print_help (void)
 
 	/* SNMP and Authentication Protocol */
 	printf (" %s\n", "-n, --next");
-  printf ("    %s\n", _("Use SNMP GETNEXT instead of SNMP GET"));
-  printf (" %s\n", "-P, --protocol=[1|2c|3]");
-  printf ("    %s\n", _("SNMP protocol version"));
-  printf (" %s\n", "-L, --seclevel=[noAuthNoPriv|authNoPriv|authPriv]");
-  printf ("    %s\n", _("SNMPv3 securityLevel"));
-  printf (" %s\n", "-a, --authproto=[MD5|SHA]");
-  printf ("    %s\n", _("SNMPv3 auth proto"));
+	printf ("    %s\n", _("Use SNMP GETNEXT instead of SNMP GET"));
+	printf (" %s\n", "-P, --protocol=[1|2c|3]");
+	printf ("    %s\n", _("SNMP protocol version"));
+	printf (" %s\n", "-L, --seclevel=[noAuthNoPriv|authNoPriv|authPriv]");
+	printf ("    %s\n", _("SNMPv3 securityLevel"));
+	printf (" %s\n", "-a, --authproto=[MD5|SHA]");
+	printf ("    %s\n", _("SNMPv3 auth proto"));
+	printf (" %s\n", "-x, --privproto=[DES|AES]");
+	printf ("    %s\n", _("SNMPv3 priv proto (default DES)"));
 
 	/* Authentication Tokens*/
 	printf (" %s\n", "-C, --community=STRING");
-  printf ("    %s ", _("Optional community string for SNMP communication"));
-  printf ("(%s \"%s\")\n", _("default is") ,DEFAULT_COMMUNITY);
-  printf (" %s\n", "-U, --secname=USERNAME");
-  printf ("    %s\n", _("SNMPv3 username"));
-  printf (" %s\n", "-A, --authpassword=PASSWORD");
-  printf ("    %s\n", _("SNMPv3 authentication password"));
-  printf (" %s\n", "-X, --privpasswd=PASSWORD");
-  printf ("    %s\n", _("SNMPv3 privacy password"));
+	printf ("    %s ", _("Optional community string for SNMP communication"));
+	printf ("(%s \"%s\")\n", _("default is") ,DEFAULT_COMMUNITY);
+	printf (" %s\n", "-U, --secname=USERNAME");
+	printf ("    %s\n", _("SNMPv3 username"));
+	printf (" %s\n", "-A, --authpassword=PASSWORD");
+	printf ("    %s\n", _("SNMPv3 authentication password"));
+	printf (" %s\n", "-X, --privpasswd=PASSWORD");
+	printf ("    %s\n", _("SNMPv3 privacy password"));
 
 	/* OID Stuff */
 	printf (" %s\n", "-o, --oid=OID(s)");
-  printf ("    %s\n", _("Object identifier(s) or SNMP variables whose value you wish to query"));
-  printf (" %s\n", "-m, --miblist=STRING");
-  printf ("    %s\n", _("List of MIBS to be loaded (default = none if using numeric oids or 'ALL'"));
-  printf ("    %s\n", _("for symbolic oids.)"));
-  printf (" %s\n", "-d, --delimiter=STRING");
-  printf (_("    Delimiter to use when parsing returned data. Default is \"%s\""), DEFAULT_DELIMITER);
-  printf ("    %s\n", _("Any data on the right hand side of the delimiter is considered"));
-  printf ("    %s\n", _("to be the data that should be used in the evaluation."));
+	printf ("    %s\n", _("Object identifier(s) or SNMP variables whose value you wish to query"));
+	printf (" %s\n", "-m, --miblist=STRING");
+	printf ("    %s\n", _("List of MIBS to be loaded (default = none if using numeric OIDs or 'ALL'"));
+	printf ("    %s\n", _("for symbolic OIDs.)"));
+	printf (" %s\n", "-d, --delimiter=STRING");
+	printf ("    %s \"%s\"\n", _("Delimiter to use when parsing returned data. Default is"), DEFAULT_DELIMITER);
+	printf ("    %s\n", _("Any data on the right hand side of the delimiter is considered"));
+	printf ("    %s\n", _("to be the data that should be used in the evaluation."));
 
 	/* Tests Against Integers */
-	printf (" %s\n", "-w, --warning=INTEGER_RANGE(s)");
-  printf ("    %s\n", _("Range(s) which will not result in a WARNING status"));
-  printf (" %s\n", "-c, --critical=INTEGER_RANGE(s)");
-  printf ("    %s\n", _("Range(s) which will not result in a CRITICAL status"));
+	printf (" %s\n", "-w, --warning=THRESHOLD(s)");
+	printf ("    %s\n", _("Warning threshold range(s)"));
+	printf (" %s\n", "-c, --critical=THRESHOLD(s)");
+	printf ("    %s\n", _("Critical threshold range(s)"));
 
 	/* Tests Against Strings */
 	printf (" %s\n", "-s, --string=STRING");
-  printf ("    %s\n", _("Return OK state (for that OID) if STRING is an exact match"));
-  printf (" %s\n", "-r, --ereg=REGEX");
-  printf ("    %s\n", _("Return OK state (for that OID) if extended regular expression REGEX matches"));
-  printf (" %s\n", "-R, --eregi=REGEX");
-  printf ("    %s\n", _("Return OK state (for that OID) if case-insensitive extended REGEX matches"));
-  printf (" %s\n", "-l, --label=STRING");
-  printf ("    %s\n", _("Prefix label for output from plugin (default -s 'SNMP')"));
+	printf ("    %s\n", _("Return OK state (for that OID) if STRING is an exact match"));
+	printf (" %s\n", "-r, --ereg=REGEX");
+	printf ("    %s\n", _("Return OK state (for that OID) if extended regular expression REGEX matches"));
+	printf (" %s\n", "-R, --eregi=REGEX");
+	printf ("    %s\n", _("Return OK state (for that OID) if case-insensitive extended REGEX matches"));
+	printf (" %s\n", "-l, --label=STRING");
+	printf ("    %s\n", _("Prefix label for output from plugin (default -s 'SNMP')"));
 
 	/* Output Formatting */
 	printf (" %s\n", "-u, --units=STRING");
-  printf ("    %s\n", _("Units label(s) for output data (e.g., 'sec.')."));
-  printf (" %s\n", "-D, --output-delimiter=STRING");
-  printf ("    %s\n", _("Separates output on multiple OID requests"));
+	printf ("    %s\n", _("Units label(s) for output data (e.g., 'sec.')."));
+	printf (" %s\n", "-D, --output-delimiter=STRING");
+	printf ("    %s\n", _("Separates output on multiple OID requests"));
 
 	printf (_(UT_TIMEOUT), DEFAULT_SOCKET_TIMEOUT);
+	printf (" %s\n", "-e, --retries=INTEGER");
+	printf ("    %s\n", _("Number of retries to be used in the requests"));
 
 	printf (_(UT_VERBOSE));
 
-  printf ("\n");
-  printf ("%s\n", _("This plugin uses the 'snmpget' command included with the NET-SNMP package."));
-  printf ("%s\n", _("if you don't have the package installed, you will need to download it from"));
-  printf ("%s\n", _("http://net-snmp.sourceforge.net before you can use this plugin."));
+	printf ("\n");
+	printf ("%s\n", _("This plugin uses the 'snmpget' command included with the NET-SNMP package."));
+	printf ("%s\n", _("if you don't have the package installed, you will need to download it from"));
+	printf ("%s\n", _("http://net-snmp.sourceforge.net before you can use this plugin."));
 
-  printf ("\n");
-  printf ("%s\n", _("Notes:"));
-  printf (" %s\n", _("- Multiple OIDs may be indicated by a comma- or space-delimited list (lists with"));
-  printf ("   %s\n", _("internal spaces must be quoted) [max 8 OIDs]"));
+	printf ("\n");
+	printf ("%s\n", _("Notes:"));
+	printf (" %s\n", _("- Multiple OIDs may be indicated by a comma- or space-delimited list (lists with"));
+	printf ("   %s\n", _("internal spaces must be quoted) [max 8 OIDs]"));
 
-  printf (" %s\n", _("- Ranges are inclusive and are indicated with colons. When specified as"));
-  printf ("   %s\n", _("'min:max' a STATE_OK will be returned if the result is within the indicated"));
-  printf ("   %s\n", _("range or is equal to the upper or lower bound. A non-OK state will be"));
-  printf ("   %s\n", _("returned if the result is outside the specified range."));
+	printf(" -%s", _(UT_THRESHOLDS_NOTES));
 
-  printf (" %s\n", _("- If specified in the order 'max:min' a non-OK state will be returned if the"));
-  printf ("   %s\n", _("result is within the (inclusive) range."));
-
-  printf (" %s\n", _("- Upper or lower bounds may be omitted to skip checking the respective limit."));
-  printf (" %s\n", _("- Bare integers are interpreted as upper limits."));
-  printf (" %s\n", _("- When checking multiple OIDs, separate ranges by commas like '-w 1:10,1:,:20'"));
-  printf (" %s\n", _("- Note that only one string and one regex may be checked at present"));
-  printf (" %s\n", _("- All evaluation methods other than PR, STR, and SUBSTR expect that the value"));
-  printf ("   %s\n", _("returned from the SNMP query is an unsigned integer."));
+	printf (" %s\n", _("- When checking multiple OIDs, separate ranges by commas like '-w 1:10,1:,:20'"));
+	printf (" %s\n", _("- Note that only one string and one regex may be checked at present"));
+	printf (" %s\n", _("- All evaluation methods other than PR, STR, and SUBSTR expect that the value"));
+	printf ("   %s\n", _("returned from the SNMP query is an unsigned integer."));
 #ifdef NP_EXTRA_OPTS
-  printf (" -%s", _(UT_EXTRA_OPTS_NOTES));
+	printf (" -%s", _(UT_EXTRA_OPTS_NOTES));
 #endif
 
 	printf (_(UT_SUPPORT));
@@ -1037,10 +897,10 @@ print_help (void)
 void
 print_usage (void)
 {
-  printf (_("Usage:"));
+	printf (_("Usage:"));
 	printf ("%s -H <ip_address> -o <OID> [-w warn_range] [-c crit_range]\n",progname);
-  printf ("[-C community] [-s string] [-r regex] [-R regexi] [-t timeout] [-e retries]\n");
-  printf ("[-l label] [-u units] [-p port-number] [-d delimiter] [-D output-delimiter]\n");
-  printf ("[-m miblist] [-P snmp version] [-L seclevel] [-U secname] [-a authproto]\n");
-  printf ("[-A authpasswd] [-X privpasswd]\n");
+	printf ("[-C community] [-s string] [-r regex] [-R regexi] [-t timeout] [-e retries]\n");
+	printf ("[-l label] [-u units] [-p port-number] [-d delimiter] [-D output-delimiter]\n");
+	printf ("[-m miblist] [-P snmp version] [-L seclevel] [-U secname] [-a authproto]\n");
+	printf ("[-A authpasswd] [-x privproto] [-X privpasswd]\n");
 }
